<?php
/**
 * OAuth2 configuration functions for news_client.
 */

/**
 * Page callback for admin/config/services/news_client/oauth2.
 */
function news_client_oauth2_page() {
  $config_file_path = _news_client_get_config_file_path();
  
  if (!file_exists($config_file_path)) {
    drupal_set_message(t('News Client OAuth2 config file not found at :path', array(':path' => $config_file_path)), 'warning', FALSE);
  }
  
  $build = array();
  
  $build['form'] = drupal_get_form('news_client_oauth2_settings_form');
  
  return $build;
}

/**
 * Admin settings form.
 */
function news_client_oauth2_settings_form() {  
  $config_file_path = variable_get('news_client_config_file_path', '/tmp/news_client_oauth2_config.txt');
  $pantheon_support_enabled = variable_get('news_client_pantheon_support_enabled', 0);
  
  $form = array();
  
  $form['news_client_config_file_path'] = array(
    '#type' => 'textfield',
    '#title' => t('OAuth2 Configuration File Path'),
    '#description' => t('The location of the configuration file.'),
    '#default_value' => $config_file_path,
    '#size' => 100,
    '#required' => TRUE,
  );
  
  if ($pantheon_support_enabled && isset($_SERVER['PRESSFLOW_SETTINGS'])) {
    // Add prefix to config file path field.
    $pressflow_settings = json_decode($_SERVER['PRESSFLOW_SETTINGS'], TRUE);
    $pantheon_binding = $pressflow_settings['conf']['pantheon_binding'];
  
    $form['news_client_config_file_path']['#field_prefix'] = '/srv/bindings/' . $pantheon_binding . '/';
  
    $form['news_client_config_file_path']['#description'] .= ' <strong>Note:</strong> Pantheon support enabled. A location starting at the server root is assumed.';
  }
  
  $form['advanced'] = array(
    '#type' => 'fieldset',
    '#title' => t('Advanced'),
    '#description' => t('Advanced configuration settings.'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  
  $form['advanced']['news_client_pantheon_support_enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable Pantheon Support'),
    '#description' => t('Enables support for adding configuration file into Pantheon\'s server root. (i.e. Figures out the current Pantheon environments binding identifier to create a path like /srv/bindings/&lt;pantheon binding&gt;/&lt;etc.&gt;.)'),
    '#default_value' => $pantheon_support_enabled,
  );
  
  return system_settings_form($form);
}
